package Module::CoreList::List;

our $DATE = '2019-02-08'; # DATE
our $VERSION = '0.001'; # VERSION

1;
# ABSTRACT: List of core modules by perl version

__END__

=pod

=encoding UTF-8

=head1 NAME

Module::CoreList::List - List of core modules by perl version

=head1 VERSION

This document describes version 0.001 of Module::CoreList::List (from Perl distribution Module-CoreList-List), released on 2019-02-08.

=head1 DESCRIPTION

This distribution contains POD pages that list core modules by perl version:

=over

=item * L<Module::CoreList::List::5>

=item * L<Module::CoreList::List::5_001>

=item * L<Module::CoreList::List::5_002>

=item * L<Module::CoreList::List::5_00307>

=item * L<Module::CoreList::List::5_004>

=item * L<Module::CoreList::List::5_00405>

=item * L<Module::CoreList::List::5_005>

=item * L<Module::CoreList::List::5_00503>

=item * L<Module::CoreList::List::5_00504>

=item * L<Module::CoreList::List::v5_10_0>

=item * L<Module::CoreList::List::v5_10_1>

=item * L<Module::CoreList::List::v5_11_0>

=item * L<Module::CoreList::List::v5_11_1>

=item * L<Module::CoreList::List::v5_11_2>

=item * L<Module::CoreList::List::v5_11_3>

=item * L<Module::CoreList::List::v5_11_4>

=item * L<Module::CoreList::List::v5_11_5>

=item * L<Module::CoreList::List::v5_12_0>

=item * L<Module::CoreList::List::v5_12_1>

=item * L<Module::CoreList::List::v5_12_2>

=item * L<Module::CoreList::List::v5_12_3>

=item * L<Module::CoreList::List::v5_12_4>

=item * L<Module::CoreList::List::v5_12_5>

=item * L<Module::CoreList::List::v5_13_0>

=item * L<Module::CoreList::List::v5_13_1>

=item * L<Module::CoreList::List::v5_13_10>

=item * L<Module::CoreList::List::v5_13_11>

=item * L<Module::CoreList::List::v5_13_2>

=item * L<Module::CoreList::List::v5_13_3>

=item * L<Module::CoreList::List::v5_13_4>

=item * L<Module::CoreList::List::v5_13_5>

=item * L<Module::CoreList::List::v5_13_6>

=item * L<Module::CoreList::List::v5_13_7>

=item * L<Module::CoreList::List::v5_13_8>

=item * L<Module::CoreList::List::v5_13_9>

=item * L<Module::CoreList::List::v5_14_0>

=item * L<Module::CoreList::List::v5_14_1>

=item * L<Module::CoreList::List::v5_14_2>

=item * L<Module::CoreList::List::v5_14_3>

=item * L<Module::CoreList::List::v5_14_4>

=item * L<Module::CoreList::List::v5_15_0>

=item * L<Module::CoreList::List::v5_15_1>

=item * L<Module::CoreList::List::v5_15_2>

=item * L<Module::CoreList::List::v5_15_3>

=item * L<Module::CoreList::List::v5_15_4>

=item * L<Module::CoreList::List::v5_15_5>

=item * L<Module::CoreList::List::v5_15_6>

=item * L<Module::CoreList::List::v5_15_7>

=item * L<Module::CoreList::List::v5_15_8>

=item * L<Module::CoreList::List::v5_15_9>

=item * L<Module::CoreList::List::v5_16_0>

=item * L<Module::CoreList::List::v5_16_1>

=item * L<Module::CoreList::List::v5_16_2>

=item * L<Module::CoreList::List::v5_16_3>

=item * L<Module::CoreList::List::v5_17_0>

=item * L<Module::CoreList::List::v5_17_1>

=item * L<Module::CoreList::List::v5_17_10>

=item * L<Module::CoreList::List::v5_17_11>

=item * L<Module::CoreList::List::v5_17_2>

=item * L<Module::CoreList::List::v5_17_3>

=item * L<Module::CoreList::List::v5_17_4>

=item * L<Module::CoreList::List::v5_17_5>

=item * L<Module::CoreList::List::v5_17_6>

=item * L<Module::CoreList::List::v5_17_7>

=item * L<Module::CoreList::List::v5_17_8>

=item * L<Module::CoreList::List::v5_17_9>

=item * L<Module::CoreList::List::v5_18_0>

=item * L<Module::CoreList::List::v5_18_1>

=item * L<Module::CoreList::List::v5_18_2>

=item * L<Module::CoreList::List::v5_18_3>

=item * L<Module::CoreList::List::v5_18_4>

=item * L<Module::CoreList::List::v5_19_0>

=item * L<Module::CoreList::List::v5_19_1>

=item * L<Module::CoreList::List::v5_19_10>

=item * L<Module::CoreList::List::v5_19_11>

=item * L<Module::CoreList::List::v5_19_2>

=item * L<Module::CoreList::List::v5_19_3>

=item * L<Module::CoreList::List::v5_19_4>

=item * L<Module::CoreList::List::v5_19_5>

=item * L<Module::CoreList::List::v5_19_6>

=item * L<Module::CoreList::List::v5_19_7>

=item * L<Module::CoreList::List::v5_19_8>

=item * L<Module::CoreList::List::v5_19_9>

=item * L<Module::CoreList::List::v5_20_0>

=item * L<Module::CoreList::List::v5_20_1>

=item * L<Module::CoreList::List::v5_20_2>

=item * L<Module::CoreList::List::v5_20_3>

=item * L<Module::CoreList::List::v5_21_0>

=item * L<Module::CoreList::List::v5_21_1>

=item * L<Module::CoreList::List::v5_21_10>

=item * L<Module::CoreList::List::v5_21_11>

=item * L<Module::CoreList::List::v5_21_2>

=item * L<Module::CoreList::List::v5_21_3>

=item * L<Module::CoreList::List::v5_21_4>

=item * L<Module::CoreList::List::v5_21_5>

=item * L<Module::CoreList::List::v5_21_6>

=item * L<Module::CoreList::List::v5_21_7>

=item * L<Module::CoreList::List::v5_21_8>

=item * L<Module::CoreList::List::v5_21_9>

=item * L<Module::CoreList::List::v5_22_0>

=item * L<Module::CoreList::List::v5_22_1>

=item * L<Module::CoreList::List::v5_22_2>

=item * L<Module::CoreList::List::v5_22_3>

=item * L<Module::CoreList::List::v5_22_4>

=item * L<Module::CoreList::List::v5_23_0>

=item * L<Module::CoreList::List::v5_23_1>

=item * L<Module::CoreList::List::v5_23_2>

=item * L<Module::CoreList::List::v5_23_3>

=item * L<Module::CoreList::List::v5_23_4>

=item * L<Module::CoreList::List::v5_23_5>

=item * L<Module::CoreList::List::v5_23_6>

=item * L<Module::CoreList::List::v5_23_7>

=item * L<Module::CoreList::List::v5_23_8>

=item * L<Module::CoreList::List::v5_23_9>

=item * L<Module::CoreList::List::v5_24_0>

=item * L<Module::CoreList::List::v5_24_1>

=item * L<Module::CoreList::List::v5_24_2>

=item * L<Module::CoreList::List::v5_24_3>

=item * L<Module::CoreList::List::v5_24_4>

=item * L<Module::CoreList::List::v5_25_0>

=item * L<Module::CoreList::List::v5_25_1>

=item * L<Module::CoreList::List::v5_25_10>

=item * L<Module::CoreList::List::v5_25_11>

=item * L<Module::CoreList::List::v5_25_12>

=item * L<Module::CoreList::List::v5_25_2>

=item * L<Module::CoreList::List::v5_25_3>

=item * L<Module::CoreList::List::v5_25_4>

=item * L<Module::CoreList::List::v5_25_5>

=item * L<Module::CoreList::List::v5_25_6>

=item * L<Module::CoreList::List::v5_25_7>

=item * L<Module::CoreList::List::v5_25_8>

=item * L<Module::CoreList::List::v5_25_9>

=item * L<Module::CoreList::List::v5_26_0>

=item * L<Module::CoreList::List::v5_26_1>

=item * L<Module::CoreList::List::v5_26_2>

=item * L<Module::CoreList::List::v5_26_3>

=item * L<Module::CoreList::List::v5_27_0>

=item * L<Module::CoreList::List::v5_27_1>

=item * L<Module::CoreList::List::v5_27_10>

=item * L<Module::CoreList::List::v5_27_11>

=item * L<Module::CoreList::List::v5_27_2>

=item * L<Module::CoreList::List::v5_27_3>

=item * L<Module::CoreList::List::v5_27_4>

=item * L<Module::CoreList::List::v5_27_5>

=item * L<Module::CoreList::List::v5_27_6>

=item * L<Module::CoreList::List::v5_27_7>

=item * L<Module::CoreList::List::v5_27_8>

=item * L<Module::CoreList::List::v5_27_9>

=item * L<Module::CoreList::List::v5_28_0>

=item * L<Module::CoreList::List::v5_28_1>

=item * L<Module::CoreList::List::v5_29_0>

=item * L<Module::CoreList::List::v5_29_1>

=item * L<Module::CoreList::List::v5_29_2>

=item * L<Module::CoreList::List::v5_29_3>

=item * L<Module::CoreList::List::v5_29_4>

=item * L<Module::CoreList::List::v5_29_5>

=item * L<Module::CoreList::List::v5_29_6>

=item * L<Module::CoreList::List::v5_29_7>

=item * L<Module::CoreList::List::v5_6_0>

=item * L<Module::CoreList::List::v5_6_1>

=item * L<Module::CoreList::List::v5_6_2>

=item * L<Module::CoreList::List::v5_7_3>

=item * L<Module::CoreList::List::v5_8_0>

=item * L<Module::CoreList::List::v5_8_1>

=item * L<Module::CoreList::List::v5_8_2>

=item * L<Module::CoreList::List::v5_8_3>

=item * L<Module::CoreList::List::v5_8_4>

=item * L<Module::CoreList::List::v5_8_5>

=item * L<Module::CoreList::List::v5_8_6>

=item * L<Module::CoreList::List::v5_8_7>

=item * L<Module::CoreList::List::v5_8_8>

=item * L<Module::CoreList::List::v5_8_9>

=item * L<Module::CoreList::List::v5_9_0>

=item * L<Module::CoreList::List::v5_9_1>

=item * L<Module::CoreList::List::v5_9_2>

=item * L<Module::CoreList::List::v5_9_3>

=item * L<Module::CoreList::List::v5_9_4>

=item * L<Module::CoreList::List::v5_9_5>

=back

The data comes from L<Module::CoreList> version:

 5.20190120

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Module-CoreList-List>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Module-CoreList-List>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Module-CoreList-List>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Module::CoreList>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2019 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
